pub trait IntoVecF<F: Field> {
// Required method
fn into_vec_f(self) -> Vec<F>;
}Expand description
Simple trait which allows for ease of converting e.g. a Vec<u64>
into a Vec<F>.
pub trait IntoVecF<F: Field> {
// Required method
fn into_vec_f(self) -> Vec<F>;
}Simple trait which allows for ease of converting e.g. a Vec<u64>
into a Vec<F>.